@@ -2,18 +2,17 @@ from ..models.base import BaseModel
 
 
 class Class(BaseModel):
-    uid = None
-    name = None
-    number = None
-    description = None
-    principal_number = None  # 班主任工号
-    motto = None
-    grade = None
-    teacher_list = []
-    student_list = []
-    school = None
-
     def __init__(self, *args, **kwargs):
+        self.uid = None
+        self.name = None
+        self.number = None
+        self.description = None
+        self.principal_number = None  # 班主任工号
+        self.motto = None
+        self.grade = None
+        self.teacher_list = []
+        self.student_list = []
+        self.school = None
         super(Class, self).__init__(*args, **kwargs)
         self.principal_id = None
         self.teacher_ids = []
