@@ -28,7 +28,7 @@ class ClassroomSync(BaseSync):
             self.building_list.add(parent_id)
 
     def extract_classroom(self):
-        sql = "SELECT id, areaname, pid, levf FROM mid_areainfo ORDER BY levf"
+        sql = "SELECT id, fullname, pid, levf FROM mid_areainfo ORDER BY levf"
         self.cur.execute(sql)
         rows = self.cur.fetchall()
         for row in rows:
