@@ -18,8 +18,21 @@ class CourseSync(BaseSync):
         self.student_map = {}
         self.teacher_map = {}
         self.classroom_map = {}
+        self.class_set = set()
+        self.class_name_num = {}
         self.rest_table = None
         self.semester = None
+        self.course_name_list = []
+
+    def create_unique_course_name(self, subject_name, class_name):
+        course_name = "{}_{}".format(subject_name, class_name) if class_name else subject_name
+        new_course_name = course_name
+        while True:
+            if new_course_name not in self.course_name_list:
+                break
+            new_course_name = "{}_{}".format(course_name, str(uuid.uuid4())[:3])
+        self.course_name_list.append(new_course_name)
+        return new_course_name
 
     def extract_course(self):
         today, last_day = self.get_date_range()
@@ -34,6 +47,7 @@ class CourseSync(BaseSync):
             classroom_id, course_date, week = row[3], row[4], row[5]
             user_id, is_teacher, class_name = row[6], row[7], row[8]
             unique_key = "{}_{}_{}".format(subject_name, classroom_id, class_name)
+            # unique_key = "{}_{}".format(subject_name, classroom_id)
             course_number = get_md5_hash(unique_key)
             subject_number = get_md5_hash(subject_name)
             num = self.slot_map.get(slot_id, None)
@@ -42,20 +56,28 @@ class CourseSync(BaseSync):
                 print("Can't Find SlotID {}".format(slot_id))
                 continue
             if unique_key not in self.course_map:
-                course_data = {'name': subject_name, 'number': course_number, 'subject_number': subject_number,
-                               "subject_name": subject_name, "class_name": class_name,
-                               'classroom_number': classroom_number, 'is_walking': False,
+                course_name = self.create_unique_course_name(subject_name, class_name=class_name)
+                course_data = {'name': course_name, 'number': course_number, 'subject_number': subject_number,
+                               "subject_name": subject_name, 'classroom_number': classroom_number, 'is_walking': False,
                                "teacher_number": None, "begin_week": 1, "end_week": 8, 'student_list': []}
                 course = CourseV2(**course_data)
+                course.class_name = class_name
+                course.required_student = False
                 self.course_map[unique_key] = course
+                if class_name and class_name in self.class_name_num:
+                    self.class_set.add(self.class_name_num[class_name])
             else:
                 course = self.course_map[unique_key]
             if is_teacher:
-                teacher_number = self.teacher_map.get(user_id, None)
-                course.teacher_number = teacher_number
+                if str(user_id) in ["1", "4"]:
+                    continue
+                teacher_number = self.teacher_map.get(user_id)
+                if teacher_number:
+                    course.teacher_number = teacher_number
             else:
-                student_number = self.student_map.get(user_id, None)
-                course.add_student(student_number)
+                student_number = self.student_map.get(user_id)
+                if student_number:
+                    course.add_student(student_number)
             course.add_position(num, week, category, classroom_number)
 
     def sync(self):
@@ -70,6 +92,7 @@ class CourseSync(BaseSync):
                                             rest_name=self.rest_table.name, walking_mode=WalkingModeSet.WALKING,
                                             begin_date=begin_date, end_date=end_date, semester_name=self.semester.name)
         course_table.classrooms_num = list(self.classroom_map.values())
+        course_table.sections_num = list(self.class_set)
         course_table.courses = list(self.course_map.values())
         print(">>> CREATE_COURSE_TABLE")
         logger.info(">>> CREATE_COURSE_TABLE")
