@@ -15,6 +15,8 @@ class ScheduleSync(BaseSync):
         super(ScheduleSync, self).__init__()
         self.offset = 300
         self.slot_map = {}
+        self.semester = None
+        self.rest_table = None
 
     def wrap_time(self, ts):
         return "{}:00".format(ts) if len(ts) < 6 else ts
@@ -55,3 +57,5 @@ class ScheduleSync(BaseSync):
         self.client.create_semester(self.school_id, semester)
         self.client.create_rest_table(self.school_id, rest_table, is_active=True)
         self.close_db()
+        self.semester = semester
+        self.rest_table = rest_table
