@@ -130,15 +130,16 @@ class CourseSyncV2(BaseSync2):
         begin_datetime = datetime.datetime.now()
         end_datetime = begin_datetime + datetime.timedelta(days=60)
         begin_date, end_date = date2str(begin_datetime.date()), date2str(end_datetime.date())
-        semester = SemesterV2(name=response['semester'], begin_date=begin_date, end_date=end_date,
-                              number=get_md5_hash(response['semester'])[:20])
+        semester_name = response['semester'] or "当前学期"
+        semester = SemesterV2(name=semester_name, begin_date=begin_date, end_date=end_date,
+                              number=get_md5_hash(semester_name)[:20])
         rest_table = RestTableV2(name="全校作息", number=get_md5_hash("全校作息")[:20], semester_name=semester.name)
         rest_table_info = response.get('timeSettings', [])
         if not response.get('schedule', None):
             return
         self.create_school_rest_table(rest_table, rest_table_info)
         self.related_member()
-        course_table_name = "{}课表_{}".format(response['semester'], str(uuid.uuid4())[:4])
+        course_table_name = "{}课表_{}".format(semester_name, str(uuid.uuid4())[:4])
         course_table_number = get_md5_hash(course_table_name)[:20]
         walking_mode = WalkingModeSet.WALKING if self.is_walking else WalkingModeSet.NOT_WALKING
         course_table = CourseTableManagerV2(name=course_table_name, number=course_table_number,
